@@ -3,7 +3,6 @@ import uuid
 
 from pathlib import Path
 
-from vantage6.common import create_random_string
 from vantage6.cli.context import NodeContext, ServerContext
 from vantage6.cli.configuration_manager import (
     NodeConfigurationManager,
@@ -76,6 +75,14 @@ def node_configuration_questionaire(dirs, instance_name):
                    choices=["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL",
                             "NOTSET"]).ask()
 
+    is_add_vpn = q.confirm(
+        "Do you want to connect to a VPN server?", default=False).ask()
+    if is_add_vpn:
+        config['vpn_subnet'] = q.text(
+            message="Subnet of the VPN server you want to connect to:",
+            default='10.76.0.0/16'
+        ).ask()
+
     config["logging"] = {
         "level": res,
         "file": f"{instance_name}.log",
@@ -149,6 +156,52 @@ def server_configuration_questionaire(dirs, instance_name):
                    choices=["DEBUG", "INFO", "WARNING", "ERROR",
                             "CRITICAL", "NOTSET"]).ask()
 
+    is_add_vpn = q.confirm(
+        "Do you want to add a VPN server?", default=False).ask()
+    if is_add_vpn:
+        vpn_config = q.prompt([
+            {
+                "type": "text",
+                "name": "url",
+                "message": "VPN server URL:",
+            },
+            {
+                "type": "text",
+                "name": "portal_username",
+                "message": "VPN portal username:",
+            },
+            {
+                "type": "password",
+                "name": "portal_userpass",
+                "message": "VPN portal password:",
+            },
+            {
+                "type": "text",
+                "name": "client_id",
+                "message": "VPN client username:",
+            },
+            {
+                "type": "password",
+                "name": "client_secret",
+                "message": "VPN client password:",
+            },
+            {
+                "type": "text",
+                "name": "redirect_url",
+                "message": "Redirect url (should be local address of server)",
+                "default": "http://localhost"
+            }
+        ])
+        config['vpn_server'] = vpn_config
+
+    is_add_rabbitmq = q.confirm(
+        "Do you want to add a RabbitMQ message queue?").ask()
+    if is_add_rabbitmq:
+        rabbit_uri = q.text(
+            message='Enter the URI for your RabbitMQ:'
+        ).ask()
+        config['rabbitmq_uri'] = rabbit_uri
+
     config["logging"] = {
         "level": res,
         "file": f"{instance_name}.log",
@@ -159,21 +212,6 @@ def server_configuration_questionaire(dirs, instance_name):
         "datefmt": "%Y-%m-%d %H:%M:%S"
     }
 
-    is_add_rabbitmq = q.confirm(
-        "Do you want to add a RabbitMQ message queue?").ask()
-    if is_add_rabbitmq:
-        r_user = q.text(
-            message='Enter a new RabbitMQ username:', default='guest'
-        ).ask()
-        r_pass = q.text(
-            message='Enter a new RabbitMQ password:',
-            default=create_random_string()
-        ).ask()
-        config['rabbitmq'] = {
-            'user': r_user,
-            'password': r_pass,
-        }
-
     return config
 
 
